@@ -26,8 +26,8 @@ function bindMousetrap(prev, next) {
 }
 
 function findLastOverlay () {
-  var all = $('[msOverlay]').map(function(){ 
-    return $(this).attr('msOverlay').split('-');
+  var all = $('[ms_overlay]').map(function(){ 
+    return $(this).attr('ms_overlay').split('-');
   }).map(function(){
     return this.length ? parseInt(this) : null;
   }).toArray();
@@ -65,8 +65,8 @@ function parseOverlaySpec (str) {
 }
 
 function refreshOverlays () {
-  $('[msOverlay]').each(function(){
-    spec = parseOverlaySpec($(this).attr('msOverlay'));
+  $('[ms_overlay]').each(function(){
+    spec = parseOverlaySpec($(this).attr('ms_overlay'));
     if ( current >= spec[0] && current <= spec[1] ) {
       $(this).show();
     } else {
